@@ -20,10 +20,14 @@
 #include <KCrash>
 #include <QApplication>
 #include <KLocalizedString>
-#include <kdelibs4configmigrator.h>
+#include <Kdelibs4ConfigMigrator>
 
 #include "mainwindow.h"
+#include "knetwalk_version.h"
 #include <KDBusService>
+
+#include <QCommandLineParser>
+
 static const char description[] =
 I18N_NOOP("KNetWalk, a game for system administrators.");
 
@@ -32,8 +36,6 @@ I18N_NOOP("(C) 2004-2005 Andi Peredri, ported to KDE by Thomas Nagy\n"
           "(C) 2007-2008 Fela Winkelmolen\n"
           "(C) 2013 Ashwin Rajeev");
 
-static const char version[] = "3.3.0";
-
 int main(int argc, char ** argv)
 {
     QApplication app(argc, argv);
@@ -46,9 +48,9 @@ int main(int argc, char ** argv)
     migrate.migrate();
 
     KAboutData about(QStringLiteral("knetwalk"), i18n("KNetWalk"),
-                         QLatin1String(version), i18n(description),
+                         QStringLiteral(KNETWALK_VERSION_STRING), i18n(description),
                          KAboutLicense::GPL, i18n(copyleft), QString(),
-                         QStringLiteral("http://games.kde.org/knetwalk"));
+                         QStringLiteral("https://kde.org/applications/games/org.kde.knetwalk"));
     
     about.addAuthor(i18n("Andi Peredri"),
                     i18n("original author"),
@@ -75,6 +77,11 @@ int main(int argc, char ** argv)
     about.setProductName(QByteArray("knetwalk"));
     
     KAboutData::setApplicationData(about);
+    QCommandLineParser parser;
+    about.setupCommandLine(&parser);
+    parser.process(app);
+    about.processCommandLine(&parser);
+
     KCrash::initialize();
     KDBusService service;
  
